@@ -3,7 +3,7 @@ context("Git dates")
 
 test_that("Filling in is correct", {
 
-  current_year <- lubridate::year(lubridate::today())
+  current_year <- as.numeric(format(Sys.Date(), "%Y"))
 
   expect_equal(format_iso_8601(parse_date("8/21")),
                paste0(current_year, "-08-21T00:00:00+00:00"))
